import { defineConfig } from 'astro/config';

// Environment Variables
import {
    SITE_PROTOCOL,
    SITE_DOMAIN,
    SITE_BASE
} from './src/utils/GetConfig'

// Adapters
import node from '@astrojs/node';

// Integrations
import keystatic from '@keystatic/astro';
import mdx from '@astrojs/mdx';
import partytown from '@astrojs/partytown';
import react from '@astrojs/react';

export default defineConfig({
    // Information
    site: SITE_PROTOCOL + '://' + SITE_DOMAIN,
    base: SITE_BASE,
    // Integrations
    integrations: [
        mdx(),
        partytown(),
        react(),
        // Disable Keystatic in production
        // https://keystatic.com/docs/recipes/astro-disable-admin-ui-in-production
        ...(process.env.SKIP_KEYSTATIC ? [] : [keystatic()])
    ],
    // Server Output
    output: "hybrid",
    prefetch: true,
    adapter: node({
      mode: 'standalone',
    }),
    server: {
        port: 2014,
        host: true
    },
    // Others
    devToolbar: {
        enabled: false
    }
});